==> ev_framework-3.0.8.tar.gz: lib/_FrameWork/vImage.dart <==
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:transparent_image/transparent_image.dart';
import 'Ev/_ImageSlide.dart';
import 'Ev/_Image_Get.dart';

import './vController.dart';
import './vSystem.dart';
import 'Ev/_PhotoView.dart';
import 'Ev/_ProductImage.dart';


class vImage extends StatefulWidget {
  var image;

  List _image_slide;
  List _image_slide_url;
  bool _image_slide_auto;
  bool _isslide = true;
  bool _hasloading = true;
  String sKey;

  _vImagestate _stateitem;

  double _width = null;
  double _height = null;
  bool _fadein = true;

  double _ratio = 0;
  BoxFit _boxFit = BoxFit.cover;
  bool _zoom = false;
  bool _remove = false;

  Color _border_color = Colors.transparent;
  double _border_width = 0;
  Color _bg_color = Colors.transparent;

  var _margin = EdgeInsets.all(0);

  double _opacity = 1.0;
  bool _shadow = false;
  double _shadow_width = 0;

  var _device_hide = [0,0,0,0,0,0];

  var _onpress = null;
  var _onchange_image = null;
  double _onchange_crop_ratio = 0;

  double _round = 0;

  vImage({this.image,this.sKey=""});

  vImage r(double round)
  { this._round = round;
  return this;
  }


  vImage bg_c(Color background_color)
  { this._bg_color = background_color;
  return this;
  }

  vImage w(double width)
  { this._width = width; return this;}

  vImage h(double height)
  { this._height = height; return this; }


  vImage wh(double width,double height)
  {  this._width = width;
  this._height = height;
  return this;
  }

  vImage noLoading()
  {  this._hasloading = false;
  return this;
  }

  vImage noFadeIn()
  {  this._fadein = false;
  return this;
  }

  vImage ratio(double sizeRatio)
  { this._ratio = sizeRatio; return this; }

  vImage box_contain()
  { this._boxFit = BoxFit.contain; return this; }

  vImage cover()
  { this._boxFit = BoxFit.cover; return this; }

  vImage fill()
  { this._boxFit = BoxFit.fill; return this; }

  vImage zoom()
  { this._zoom = true; return this; }

  vImage size(double size)
  { this._width = size;
  this._height = size;
  this._ratio = 1;
  return this;
  }

  vImage circle(double size) {
    this._width = size;
    this._height = size;
    this._round = size / 2;
    this._ratio = 1;
    return this;
  }

  vImage border({double border_width = 1 ,Color border_Color = Colors.black12}) {
    this._border_color = border_Color;
    this._border_width = border_width;
    return this;
  }

  vImage m(double margin_value)
  { this._margin = EdgeInsets.all(margin_value); return this; }

  vImage mx(double margin_value)
  { this._margin = EdgeInsets.symmetric(horizontal: margin_value);  return this;}

  vImage my(double margin_value)
  { this._margin = EdgeInsets.symmetric(vertical: margin_value);  return this;}

  vImage sd1()
  { this._shadow = true;  this._shadow_width = 1; return this;}

  vImage sd2()
  { this._shadow = true;  this._shadow_width = 2; return this;}

  vImage sd3()
  { this._shadow = true;  this._shadow_width = 3; return this;}

  vImage sd4()
  { this._shadow = true;  this._shadow_width = 4; return this;}

  vImage sd5()
  { this._shadow = true;  this._shadow_width = 5; return this;}


  vImage hide({bool mobile=false,bool tablelet=false,bool destop=false,bool large=false})
  {  this._device_hide[0] = mobile ? 1 : 0;
  this._device_hide[1] = tablelet ? 1 : 0;
  this._device_hide[2] = destop ? 1 : 0;
  this._device_hide[3] = large ? 1 : 0;
  return this;
  }

  vImage h_M()
  {  this._device_hide[0] = 1; return this; }

  vImage h_T()
  { this._device_hide[1] = 1; return this; }

  vImage h_D()
  { this._device_hide[2] = 1; return this; }

  vImage h_L()
  { this._device_hide[3] = 1; return this; }

  vImage onPress(onPress)
  { this._onpress = onPress;
  return this;
  }

  vImage onChangvImage(onChange,{double crop_ratio = 0})
  { this._onchange_image = onChange;
  this._onchange_crop_ratio = crop_ratio;
  return this;
  }

  vImage slide(List image_path,{List url,bool autorun = false}) {
    this._image_slide = image_path;
    this._image_slide_url = url;
    this._image_slide_auto = autorun;
    this._isslide = true;
    return this;
  }

  vImage productImage(List image_path,{double ratio=1.5}) {
    this._image_slide = image_path;
    this._isslide = false;
    this._ratio = ratio;
    return this;
  }

  static vImage $skey(String skey)
  {   return $$vController.image_items[skey]; }


  static get_image(BuildContext context,{onImage,crop_ratio:0}) {
    if (kIsWeb) {
      $$Image_Get.Get_From_Gallery(context, crop_ratio: 0).then((image) {
        onImage(image);
      });
    }
    else {
      $$Image_Get.Get_Select_Image(
          context, crop_ratio: crop_ratio, onReceived: onImage);
    }
  }

  void $hide() {
    if (_stateitem != null) {
      _remove = false;
      _stateitem.show(0.0);
    }
  }

  void $show() {
    if (_stateitem != null) {
      _remove = false;
      _stateitem.show(1.0);
    }
  }

  void $remove() {
    _stateitem.setState(() {
      _remove = true;
    });
  }


  void $image(File image) {
    _stateitem.setState(() {
      this.image = image;
    });
  }


  @override
  _vImagestate createState() {
    _stateitem = _vImagestate();
    return _stateitem;
  }

}

class _vImagestate extends State<vImage> {
  var disable = false;

  bool onTap = false;
  bool onOver = false;

  var _image_type = "";

  void initState() {
    //print("sBox Init");
    $$vController.image_items[widget.sKey] = widget;
  }

  @override
  void dispose() {
    //print("sBox Despoit");
    //$$vController.image_items[widget.sKey] = null;
    super.dispose();
  }

  void show(opacity) {
    setState(() {
      widget._opacity = opacity;
    });
  }

  @override
  Widget build(BuildContext context) {
    if(widget._remove)
    {  return Container(); }

    var child = widget.image == null ? Container(): childimage();

    if(widget._image_slide != null) {
      return widget._isslide ? $$ImageSlide(Images: widget._image_slide,size_radio:widget._ratio,Url: widget._image_slide_url, autoplay: widget._image_slide_auto):
      $$ProductImage(Image_Paths:widget._image_slide,size_radio:widget._ratio,thumb_highlight_color:Colors.red);
    }

    var decoration = BoxDecoration(
      color: widget._bg_color,
      border: Border.all(
        //color: onTap ? Colors.orange : onOver ? Colors.red : widget._border_color,
        color: onTap ? Colors.orange : widget._border_color,
        //width: onTap || onOver ? 3.0 : widget._border_width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(widget._round)),
      boxShadow: widget._shadow ?
      [ BoxShadow(
        color: Colors.black.withOpacity(0.2),
        blurRadius: widget._shadow_width,
        offset: Offset(widget._shadow_width/2, widget._shadow_width/2), // changes position of shadow
      ),
      ] : null,
    );


    if (widget._ratio > 0) {
      child = AspectRatio(child: child, aspectRatio: widget._ratio,);
    }

    child = ClipRRect(
        borderRadius: BorderRadius.circular(widget._round),
        child: child);

    //print("Image width " + widget._width.toString());

    child = Container(
        width: widget._width , height: widget._height ,
        decoration: decoration,
        child: child);


    if(widget._zoom==true || widget._onpress != null || widget._onchange_image !=null)
    {  child = onPress_Widget(child); }

    child = Padding(padding: widget._margin, child: child);

    child = Opacity(
        opacity: widget._opacity,
        child: child);

    return LayoutBuilder(
        builder: (context, constraints) {
          var sid = vSystem.screensize_ID(context);
          if (widget._device_hide[sid] == 1) {
            return Container();
          }
          else {
            return child;
          }
        });
  }


  Widget onPress_Widget(Widget child) {
    return Material(
      color: Colors.transparent,
      child: InkWell(
          hoverColor: Colors.transparent,
          highlightColor: Colors.transparent,
          splashColor: Colors.transparent,
          /*
          onTapDown: (TapDownDetails details) {
            setState(() {
              onTap = true;
            });
          },
          */
          onTap: () {
            setState(() {
              onTap = false;
              onOver = false;
            });

            if(widget._onpress!=null)
            { widget._onpress(); }

            if(widget._onchange_image != null)
            {   if(kIsWeb)
            {  $$Image_Get.Get_From_Gallery(context,crop_ratio: 0).then((image){
              setState(() {
                widget.image= image;
                widget._onchange_image(image);

              });
            });
            }
            else
            {  print("Widget crop" + widget._onchange_crop_ratio.toString());
            $$Image_Get.Get_Select_Image(context,crop_ratio: widget._onchange_crop_ratio,onReceived: (image){
              setState(() {
                widget.image= image;
                widget._onchange_image(image);

              });
            }); }
            }
            else {
              print("image type " + _image_type.toString());
              if (widget._zoom && (_image_type == "file" || _image_type == "network"))
              {
                if(kIsWeb)
                {  var path = _image_type == "file" ? widget.image.path : widget.image ;
                print("zoom $path");
                //vSystem.$open_URL(path);
                Navigator.push(context, MaterialPageRoute(
                    builder: (context) => $$PhotoView(image:path)));
                }
                else {
                  Navigator.push(context, MaterialPageRoute(
                      builder: (context) => $$PhotoView(image: widget.image)));
                }
              }
            }
          },
          onHover: (isHovering) {
            setState(() {
              onOver = isHovering;
              if(!isHovering)
              {  onTap = false; }
            });
          },

          child: child),
    );
  }


  Widget childimage() {
    if (widget.image is File) {
      _image_type = "file";
      Image image;
      if(kIsWeb)
      {  image =  Image.network(widget.image.path,fit: widget._boxFit,width: widget._width,height:widget._height); }
      else
      {  image =  Image.file(widget.image, fit: widget._boxFit,
          width: widget._width,
          height: widget._height);}


      if(widget._fadein)
        return FadeInImage(
          // here `bytes` is a Uint8List containing the bytes for the in-memory image
            fit: widget._boxFit,
            placeholder: AssetImage('Asset/Image/FadeIn_Placeholder.png'),
            image: image.image

        );
    }

    if (widget.image.toString().contains("http")) {
      _image_type = "network";

      return (widget._fadein) ?
      Stack(
        children: [
          Container(padding: EdgeInsets.all(10),width:widget._width,child: Center(child: widget._hasloading ? CircularProgressIndicator(): Container())),
          FadeInImage.memoryNetwork(
            placeholder: kTransparentImage,
            image: widget.image.toString(),
            fit: widget._boxFit,
            width: widget._width ,
            height: widget._height ,
          ),
        ],
      ): Image.network(widget.image,fit: widget._boxFit,
        width: widget._width ,
        height: widget._height ,);
    }
    else {
      _image_type = "asset";
      return Image.asset(widget.image, fit: widget._boxFit,
          width: widget._width ,
          height: widget._height );
    }
  }
}

==> ev_framework-3.0.10.tar.gz: lib/_FrameWork/vImage.dart <==
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:transparent_image/transparent_image.dart';
import 'Ev/_ImageSlide.dart';
import 'Ev/_Image_Get.dart';

import './vController.dart';
import './vSystem.dart';
import 'Ev/_PhotoView.dart';
import 'Ev/_ProductImage.dart';


class vImage extends StatefulWidget {
  var image;

  List _image_slide;
  List _image_slide_url;
  bool _image_autorun;
  bool _isslide = true;
  bool _hasloading = true;
  String sKey;

  _vImagestate _stateitem;

  double _width = null;
  double _height = null;
  bool _fadein = true;

  double _ratio = 0;
  BoxFit _boxFit = BoxFit.cover;
  bool _zoom = false;
  bool _remove = false;

  Color _border_color = Colors.transparent;
  double _border_width = 0;
  Color _bg_color = Colors.transparent;

  var _margin = EdgeInsets.all(0);

  double _opacity = 1.0;
  bool _shadow = false;
  double _shadow_width = 0;

  var _device_hide = [0,0,0,0,0,0];

  var _onpress = null;
  var _onchange_image = null;
  double _onchange_crop_ratio = 0;

  double _round = 0;

  vImage({this.image,this.sKey=""});

  vImage r(double round)
  { this._round = round;
  return this;
  }


  vImage bg_c(Color background_color)
  { this._bg_color = background_color;
  return this;
  }

  vImage w(double width)
  { this._width = width; return this;}

  vImage h(double height)
  { this._height = height; return this; }


  vImage wh(double width,double height)
  {  this._width = width;
  this._height = height;
  return this;
  }

  vImage noLoading()
  {  this._hasloading = false;
  return this;
  }

  vImage noFadeIn()
  {  this._fadein = false;
  return this;
  }

  vImage ratio(double sizeRatio)
  { this._ratio = sizeRatio; return this; }

  vImage box_contain()
  { this._boxFit = BoxFit.contain; return this; }

  vImage cover()
  { this._boxFit = BoxFit.cover; return this; }

  vImage fill()
  { this._boxFit = BoxFit.fill; return this; }

  vImage zoom()
  { this._zoom = true; return this; }

  vImage size(double size)
  { this._width = size;
  this._height = size;
  this._ratio = 1;
  return this;
  }

  vImage circle(double size) {
    this._width = size;
    this._height = size;
    this._round = size / 2;
    this._ratio = 1;
    return this;
  }

  vImage border({double border_width = 1 ,Color border_Color = Colors.black12}) {
    this._border_color = border_Color;
    this._border_width = border_width;
    return this;
  }

  vImage m(double margin_value)
  { this._margin = EdgeInsets.all(margin_value); return this; }

  vImage mx(double margin_value)
  { this._margin = EdgeInsets.symmetric(horizontal: margin_value);  return this;}

  vImage my(double margin_value)
  { this._margin = EdgeInsets.symmetric(vertical: margin_value);  return this;}

  vImage sd1()
  { this._shadow = true;  this._shadow_width = 1; return this;}

  vImage sd2()
  { this._shadow = true;  this._shadow_width = 2; return this;}

  vImage sd3()
  { this._shadow = true;  this._shadow_width = 3; return this;}

  vImage sd4()
  { this._shadow = true;  this._shadow_width = 4; return this;}

  vImage sd5()
  { this._shadow = true;  this._shadow_width = 5; return this;}


  vImage hide({bool mobile=false,bool tablelet=false,bool destop=false,bool large=false})
  {  this._device_hide[0] = mobile ? 1 : 0;
  this._device_hide[1] = tablelet ? 1 : 0;
  this._device_hide[2] = destop ? 1 : 0;
  this._device_hide[3] = large ? 1 : 0;
  return this;
  }

  vImage h_M()
  {  this._device_hide[0] = 1; return this; }

  vImage h_T()
  { this._device_hide[1] = 1; return this; }

  vImage h_D()
  { this._device_hide[2] = 1; return this; }

  vImage h_L()
  { this._device_hide[3] = 1; return this; }

  vImage onPress(onPress)
  { this._onpress = onPress;
  return this;
  }

  vImage onChangvImage(onChange,{double crop_ratio = 0})
  { this._onchange_image = onChange;
  this._onchange_crop_ratio = crop_ratio;
  return this;
  }

  vImage slide(List image_path,{List url,bool autorun = false}) {
    this._image_slide = image_path;
    this._image_slide_url = url;
    this._image_autorun = autorun;
    this._isslide = true;
    return this;
  }

  vImage productImage(List image_path,{double ratio=1.5,bool autorun = false}) {
    this._image_slide = image_path;
    this._isslide = false;
    this._image_autorun = autorun;
    this._ratio = ratio;
    return this;
  }

  static vImage $skey(String skey)
  {   return $$vController.image_items[skey]; }


  static get_image(BuildContext context,{onImage,crop_ratio:0}) {
    if (kIsWeb) {
      $$Image_Get.Get_From_Gallery(context, crop_ratio: 0).then((image) {
        onImage(image);
      });
    }
    else {
      $$Image_Get.Get_Select_Image(
          context, crop_ratio: crop_ratio, onReceived: onImage);
    }
  }

  void $hide() {
    if (_stateitem != null) {
      _remove = false;
      _stateitem.show(0.0);
    }
  }

  void $show() {
    if (_stateitem != null) {
      _remove = false;
      _stateitem.show(1.0);
    }
  }

  void $remove() {
    _stateitem.setState(() {
      _remove = true;
    });
  }


  void $image(File image) {
    _stateitem.setState(() {
      this.image = image;
    });
  }


  @override
  _vImagestate createState() {
    _stateitem = _vImagestate();
    return _stateitem;
  }

}

class _vImagestate extends State<vImage> {
  var disable = false;

  bool onTap = false;
  bool onOver = false;

  var _image_type = "";

  void initState() {
    //print("sBox Init");
    $$vController.image_items[widget.sKey] = widget;
  }

  @override
  void dispose() {
    //print("sBox Despoit");
    //$$vController.image_items[widget.sKey] = null;
    super.dispose();
  }

  void show(opacity) {
    setState(() {
      widget._opacity = opacity;
    });
  }

  @override
  Widget build(BuildContext context) {
    if(widget._remove)
    {  return Container(); }

    var child = widget.image == null ? Container(): childimage();

    if(widget._image_slide != null) {
      return widget._isslide ? $$ImageSlide(Images: widget._image_slide,size_radio:widget._ratio,Url: widget._image_slide_url, autoplay: widget._image_autorun):
      $$ProductImage(Image_Paths:widget._image_slide,size_radio:widget._ratio,thumb_highlight_color:Colors.red,autoplay: widget._image_autorun);
    }

    var decoration = BoxDecoration(
      color: widget._bg_color,
      border: Border.all(
        //color: onTap ? Colors.orange : onOver ? Colors.red : widget._border_color,
        color: onTap ? Colors.orange : widget._border_color,
        //width: onTap || onOver ? 3.0 : widget._border_width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(widget._round)),
      boxShadow: widget._shadow ?
      [ BoxShadow(
        color: Colors.black.withOpacity(0.2),
        blurRadius: widget._shadow_width,
        offset: Offset(widget._shadow_width/2, widget._shadow_width/2), // changes position of shadow
      ),
      ] : null,
    );


    if (widget._ratio > 0) {
      child = AspectRatio(child: child, aspectRatio: widget._ratio,);
    }

    child = ClipRRect(
        borderRadius: BorderRadius.circular(widget._round),
        child: child);

    //print("Image width " + widget._width.toString());

    child = Container(
        width: widget._width , height: widget._height ,
        decoration: decoration,
        child: child);


    if(widget._zoom==true || widget._onpress != null || widget._onchange_image !=null)
    {  child = onPress_Widget(child); }

    child = Padding(padding: widget._margin, child: child);

    child = Opacity(
        opacity: widget._opacity,
        child: child);

    return LayoutBuilder(
        builder: (context, constraints) {
          var sid = vSystem.screensize_ID(context);
          if (widget._device_hide[sid] == 1) {
            return Container();
          }
          else {
            return child;
          }
        });
  }


  Widget onPress_Widget(Widget child) {
    return Material(
      color: Colors.transparent,
      child: InkWell(
          hoverColor: Colors.transparent,
          highlightColor: Colors.transparent,
          splashColor: Colors.transparent,
          /*
          onTapDown: (TapDownDetails details) {
            setState(() {
              onTap = true;
            });
          },
          */
          onTap: () {
            setState(() {
              onTap = false;
              onOver = false;
            });

            if(widget._onpress!=null)
            { widget._onpress(); }

            if(widget._onchange_image != null)
            {   if(kIsWeb)
            {  $$Image_Get.Get_From_Gallery(context,crop_ratio: 0).then((image){
              setState(() {
                widget.image= image;
                widget._onchange_image(image);

              });
            });
            }
            else
            {  print("Widget crop" + widget._onchange_crop_ratio.toString());
            $$Image_Get.Get_Select_Image(context,crop_ratio: widget._onchange_crop_ratio,onReceived: (image){
              setState(() {
                widget.image= image;
                widget._onchange_image(image);

              });
            }); }
            }
            else {
              print("image type " + _image_type.toString());
              if (widget._zoom && (_image_type == "file" || _image_type == "network"))
              {
                if(kIsWeb)
                {  var path = _image_type == "file" ? widget.image.path : widget.image ;
                print("zoom $path");
                //vSystem.$open_URL(path);
                Navigator.push(context, MaterialPageRoute(
                    builder: (context) => $$PhotoView(image:path)));
                }
                else {
                  Navigator.push(context, MaterialPageRoute(
                      builder: (context) => $$PhotoView(image: widget.image)));
                }
              }
            }
          },
          onHover: (isHovering) {
            setState(() {
              onOver = isHovering;
              if(!isHovering)
              {  onTap = false; }
            });
          },

          child: child),
    );
  }


  Widget childimage() {
    if (widget.image is File) {
      _image_type = "file";
      Image image;
      if(kIsWeb)
      {  image =  Image.network(widget.image.path,fit: widget._boxFit,width: widget._width,height:widget._height); }
      else
      {  image =  Image.file(widget.image, fit: widget._boxFit,
          width: widget._width,
          height: widget._height);}


      if(widget._fadein)
        return FadeInImage(
          // here `bytes` is a Uint8List containing the bytes for the in-memory image
            fit: widget._boxFit,
            placeholder: AssetImage('Asset/Image/FadeIn_Placeholder.png'),
            image: image.image

        );
    }

    if (widget.image.toString().contains("http")) {
      _image_type = "network";

      return (widget._fadein) ?
      Stack(
        children: [
          Container(padding: EdgeInsets.all(10),width:widget._width,child: Center(child: widget._hasloading ? CircularProgressIndicator(): Container())),
          FadeInImage.memoryNetwork(
            placeholder: kTransparentImage,
            image: widget.image.toString(),
            fit: widget._boxFit,
            width: widget._width ,
            height: widget._height ,
          ),
        ],
      ): Image.network(widget.image,fit: widget._boxFit,
        width: widget._width ,
        height: widget._height ,);
    }
    else {
      _image_type = "asset";
      return Image.asset(widget.image, fit: widget._boxFit,
          width: widget._width ,
          height: widget._height );
    }
  }
}
